@@ -35,6 +35,9 @@ public:
 
     Beading compute(coord_t thickness, coord_t bead_count) const override;
     coord_t getOptimalBeadCount(coord_t thickness) const override;
+
+private:
+    std::vector<float> calc_normalized_weights(coord_t to_be_divided, coord_t bead_count) const;
 };
 
 } // namespace Slic3r::Arachne
