@@ -17,9 +17,8 @@ class DynamicPrintConfig;
 // Load the content of an amf file into the given model and configuration.
 extern bool load_amf(const char* path, DynamicPrintConfig* config, ConfigSubstitutionContext* config_substitutions, Model* model, bool check_version);
 
-// Save the given model and the config data into an amf file.
-// The model could be modified during the export process if meshes are not repaired or have no shared vertices
-extern bool store_amf(const char* path, Model* model, const DynamicPrintConfig* config, bool fullpath_sources);
+// Function to save AMF has been removed in 2.9.0, we no longer support saving data in AMF format.
+// The option has been missing in the UI since 2.4.0 (except for CLI).
 
 } // namespace Slic3r
 
