@@ -3,10 +3,19 @@
 ///|/ PrusaSlicer is released under the terms of the AGPLv3 or higher
 ///|/
 #include "FindReplace.hpp"
-#include "../Utils.hpp"
 
-#include <cctype> // isalpha
 #include <boost/algorithm/string/replace.hpp>
+#include <boost/algorithm/string/find.hpp>
+#include <boost/range/iterator_range_core.hpp>
+#include <cctype> // isalpha
+#include <exception>
+#include <iterator>
+#include <tuple>
+#include <utility>
+#include <cstring>
+
+#include "../Utils.hpp"
+#include "libslic3r/Exception.hpp"
 
 namespace Slic3r {
 
