@@ -9,7 +9,7 @@
 #ifndef slic3r_PrintExtents_hpp_
 #define slic3r_PrintExtents_hpp_
 
-#include "libslic3r.h"
+#include "libslic3r/libslic3r.h"
 
 namespace Slic3r {
 
