@@ -3,8 +3,13 @@
 ///|/ PrusaSlicer is released under the terms of the AGPLv3 or higher
 ///|/
 #include "MutablePolygon.hpp"
-#include "Line.hpp"
+
+#include <cstdint>
+#include <utility>
+#include <cmath>
+
 #include "libslic3r.h"
+#include "libslic3r/Point.hpp"
 
 namespace Slic3r {
 
