@@ -5,9 +5,13 @@
 #ifndef ZIPPER_HPP
 #define ZIPPER_HPP
 
+#include <stddef.h>
 #include <cstdint>
 #include <string>
 #include <memory>
+#include <type_traits>
+#include <utility>
+#include <cstddef>
 
 namespace Slic3r {
 
@@ -23,6 +27,7 @@ public:
 
 private:
     class Impl;
+
     std::unique_ptr<Impl> m_impl;
     std::string m_data;
     std::string m_entry;
