@@ -5,20 +5,19 @@
 ///|/
 ///|/ PrusaSlicer is released under the terms of the AGPLv3 or higher
 ///|/
-#include "libslic3r/libslic3r.h"
-#include "GLShader.hpp"
+#include <boost/nowide/fstream.hpp>
+#include <GL/glew.h>
+#include <boost/log/trivial.hpp>
+#include <cassert>
+#include <algorithm>
+#include <cstring>
 
+#include "GLShader.hpp"
 #include "3DScene.hpp"
 #include "libslic3r/Utils.hpp"
 #include "libslic3r/format.hpp"
 #include "libslic3r/Color.hpp"
 
-#include <boost/nowide/fstream.hpp>
-#include <GL/glew.h>
-#include <cassert>
-
-#include <boost/log/trivial.hpp>
-
 namespace Slic3r {
 
 GLShaderProgram::~GLShaderProgram()
