@@ -9,7 +9,7 @@
 #include "wxExtensions.hpp"
 
 #ifdef __WXOSX__
-#include "../libslic3r/PrintConfig.hpp"
+#include "libslic3r/PrintConfig.hpp"
 #endif
 
 class wxBoxSizer;
