@@ -1,3 +1,8 @@
+///|/ Copyright (c) Prusa Research 2018 - 2022 Enrico Turri @enricoturri1966, Oleksandra Iushchenko @YuSanka, Vojtěch Bubník @bubnikv, Lukáš Matěna @lukasmatena
+///|/ Copyright (c) 2019 Maeyanie @Maeyanie
+///|/
+///|/ PrusaSlicer is released under the terms of the AGPLv3 or higher
+///|/
 #ifndef slic3r_GUI_ObjectSettings_hpp_
 #define slic3r_GUI_ObjectSettings_hpp_
 
@@ -30,6 +35,7 @@ public:
 
     virtual wxSizer*    get_sizer();
     ConfigOptionsGroup* get_og() { return m_og.get(); }
+    const ConfigOptionsGroup* get_og() const { return m_og.get(); }
     wxWindow*           parent() const {return m_parent; }
 };
 
@@ -56,7 +62,6 @@ public:
     bool        add_missed_options(ModelConfig *config_to, const DynamicPrintConfig &config_from);
     void        update_config_values(ModelConfig *config);
     void        UpdateAndShow(const bool show) override;
-    void        msw_rescale();
     void        sys_color_changed();
 };
 
