@@ -104,7 +104,7 @@ public:
     // will be also extended to support additional states, requiring at least one state to remain free out of 19 states.
     static const constexpr size_t EXTRUDERS_LIMIT = 16;
 
-    const float get_cursor_radius_min() const override { return CursorRadiusMin; }
+    float get_cursor_radius_min() const override { return CursorRadiusMin; }
 
 protected:
     ColorRGBA get_cursor_sphere_left_button_color() const override;
