@@ -225,19 +225,11 @@ void InstancesHider::render_cut() const
         else
             clipper->set_limiting_plane(ClippingPlane::ClipsNothing());
 
-#if ENABLE_GL_CORE_PROFILE || ENABLE_OPENGL_ES
         bool depth_test_enabled = ::glIsEnabled(GL_DEPTH_TEST);
-#else
-        glsafe(::glPushAttrib(GL_DEPTH_TEST));
-#endif // ENABLE_GL_CORE_PROFILE || ENABLE_OPENGL_ES
         glsafe(::glDisable(GL_DEPTH_TEST));
         clipper->render_cut(mv->is_model_part() ? ColorRGBA(0.8f, 0.3f, 0.0f, 1.0f) : color_from_model_volume(*mv));
-#if ENABLE_GL_CORE_PROFILE || ENABLE_OPENGL_ES
         if (depth_test_enabled)
             glsafe(::glEnable(GL_DEPTH_TEST));
-#else
-        glsafe(::glPopAttrib());
-#endif // ENABLE_GL_CORE_PROFILE || ENABLE_OPENGL_ES
 
         ++clipper_id;
     }
