@@ -288,7 +288,7 @@ std::vector<IconManager::Icons> IconManager::init(const std::vector<std::string>
 }
 
 void IconManager::release() {
-	BOOST_LOG_TRIVIAL(error) << "Not implemented yet";
+	BOOST_LOG_TRIVIAL(warning) << "Not implemented yet";
 }
 
 void priv::clear(IconManager::Icons &icons) {
