@@ -6,9 +6,9 @@
 #include "OpenGLManager.hpp"
 
 #include "GUI.hpp"
-#if ENABLE_GL_CORE_PROFILE
+#if !SLIC3R_OPENGL_ES
 #include "GUI_Init.hpp"
-#endif // ENABLE_GL_CORE_PROFILE
+#endif // !SLIC3R_OPENGL_ES
 #include "I18N.hpp"
 #include "3DScene.hpp"
 #include "format.hpp"
@@ -131,6 +131,9 @@ void OpenGLManager::GLInfo::detect() const
     if (!GLEW_ARB_compatibility)
         *const_cast<bool*>(&m_core_profile) = true;
 
+    int* samples = const_cast<int*>(&m_samples);
+    glsafe(::glGetIntegerv(GL_SAMPLES, samples));
+
     *const_cast<bool*>(&m_detected) = true;
 }
 
@@ -145,16 +148,16 @@ static Semver parse_version_string(const std::string& version)
     if (tokens.empty())
         return Semver::invalid();
 
-#if ENABLE_OPENGL_ES
+#if SLIC3R_OPENGL_ES
     const std::string version_container = (tokens.size() > 1 && boost::istarts_with(tokens[1], "ES")) ? tokens[2] : tokens[0];
-#endif // ENABLE_OPENGL_ES
+#endif // SLIC3R_OPENGL_ES
 
     std::vector<std::string> numbers;
-#if ENABLE_OPENGL_ES
+#if SLIC3R_OPENGL_ES
     boost::split(numbers, version_container, boost::is_any_of("."), boost::token_compress_on);
 #else
     boost::split(numbers, tokens[0], boost::is_any_of("."), boost::token_compress_on);
-#endif // ENABLE_OPENGL_ES
+#endif // SLIC3R_OPENGL_ES
 
     unsigned int gl_major = 0;
     unsigned int gl_minor = 0;
@@ -202,22 +205,23 @@ std::string OpenGLManager::GLInfo::to_string(bool for_github) const
 
     out << h2_start << "OpenGL installation" << h2_end << line_end;
     out << b_start << "GL version:   " << b_end << m_version << " (" << m_version_string << ")" << line_end;
-#if ENABLE_GL_CORE_PROFILE
+#if !SLIC3R_OPENGL_ES
     out << b_start << "Profile:      " << b_end << (is_core_profile() ? "Core" : "Compatibility") << line_end;
-#endif // ENABLE_GL_CORE_PROFILE
+#endif // !SLIC3R_OPENGL_ES
     out << b_start << "Vendor:       " << b_end << m_vendor << line_end;
     out << b_start << "Renderer:     " << b_end << m_renderer << line_end;
     out << b_start << "GLSL version: " << b_end << m_glsl_version << line_end;
     out << b_start << "Textures compression:       " << b_end << (are_compressed_textures_supported() ? "Enabled" : "Disabled") << line_end;
+    out << b_start << "Mutisampling: " << b_end << (can_multisample() ? "Enabled (" + std::to_string(m_samples) + " samples)" : "Disabled") << line_end;
 
     {
-#if ENABLE_GL_CORE_PROFILE
-        std::vector<std::string>  extensions_list = get_extensions_list();
-#else
+#if SLIC3R_OPENGL_ES
         const std::string extensions_str = gl_get_string_safe(GL_EXTENSIONS, "");
         std::vector<std::string> extensions_list;
         boost::split(extensions_list, extensions_str, boost::is_any_of(" "), boost::token_compress_on);
-#endif // ENABLE_GL_CORE_PROFILE
+#else
+        std::vector<std::string>  extensions_list = get_extensions_list();
+#endif // SLIC3R_OPENGL_ES
 
         if (!extensions_list.empty()) {
             if (for_github)
@@ -238,7 +242,7 @@ std::string OpenGLManager::GLInfo::to_string(bool for_github) const
     return out.str();
 }
 
-#if ENABLE_GL_CORE_PROFILE
+#if !SLIC3R_OPENGL_ES
 std::vector<std::string> OpenGLManager::GLInfo::get_extensions_list() const
 {
     std::vector<std::string> ret;
@@ -261,7 +265,7 @@ std::vector<std::string> OpenGLManager::GLInfo::get_extensions_list() const
 
     return ret;
 }
-#endif // ENABLE_GL_CORE_PROFILE
+#endif // !SLIC3R_OPENGL_ES
 
 OpenGLManager::GLInfo OpenGLManager::s_gl_info;
 bool OpenGLManager::s_compressed_textures_supported = false;
@@ -291,7 +295,7 @@ OpenGLManager::~OpenGLManager()
 #endif //__APPLE__
 }
 
-#if ENABLE_GL_CORE_PROFILE
+#if !SLIC3R_OPENGL_ES
 #ifdef _WIN32
 static void APIENTRY CustomGLDebugOutput(GLenum source, GLenum type, unsigned int id, GLenum severity, GLsizei length, const char* message, const void* userParam)
 #else
@@ -335,26 +339,22 @@ static void CustomGLDebugOutput(GLenum source, GLenum type, unsigned int id, GLe
     out += "]:\n";
     std::cout << out << "(" << id << "): " << message << "\n\n";
 }
-#endif // ENABLE_GL_CORE_PROFILE
+#endif // !SLIC3R_OPENGL_ES
 
 bool OpenGLManager::init_gl()
 {
     if (!m_gl_initialized) {
-#if ENABLE_GL_CORE_PROFILE || ENABLE_OPENGL_ES
-        glewExperimental = true;
-#endif // ENABLE_GL_CORE_PROFILE || ENABLE_OPENGL_ES
-        GLenum err = glewInit();
+      glewExperimental = true;
+      GLenum err = glewInit();
         if (err != GLEW_OK) {
             BOOST_LOG_TRIVIAL(error) << "Unable to init glew library: " << glewGetErrorString(err);
             return false;
         }
 
-#if ENABLE_GL_CORE_PROFILE
         do {
             // glewInit() generates an OpenGL GL_INVALID_ENUM error
             err = ::glGetError();
         } while (err != GL_NO_ERROR);
-#endif // ENABLE_GL_CORE_PROFILE
 
         m_gl_initialized = true;
 
@@ -370,27 +370,22 @@ bool OpenGLManager::init_gl()
         else
             s_framebuffers_type = EFramebufferType::Unknown;
 
-#if ENABLE_OPENGL_ES
-        bool valid_version = s_gl_info.is_version_greater_or_equal_to(2, 0);
-#elif ENABLE_GL_CORE_PROFILE
-        const bool valid_version = s_gl_info.is_version_greater_or_equal_to(3, 2);
+#if SLIC3R_OPENGL_ES
+        bool valid_version = s_gl_info.is_version_greater_or_equal_to(3, 0);
 #else
-        bool valid_version = s_gl_info.is_version_greater_or_equal_to(2, 0);
-#endif // ENABLE_OPENGL_ES
+        const bool valid_version = s_gl_info.is_version_greater_or_equal_to(3, 2);
+#endif // SLIC3R_OPENGL_ES
 
         if (!valid_version) {
             // Complain about the OpenGL version.
             wxString message = format_wxstr(
-#if ENABLE_OPENGL_ES
-                _L("PrusaSlicer requires OpenGL ES 2.0 capable graphics driver to run correctly, \n"
-                   "while OpenGL version %s, render %s, vendor %s was detected."), s_gl_info.get_version_string(), s_gl_info.get_renderer(), s_gl_info.get_vendor());
-#elif ENABLE_GL_CORE_PROFILE
-                _L("PrusaSlicer requires OpenGL 3.2 capable graphics driver to run correctly,\n"
-                   "while OpenGL version %s, render %s, vendor %s was detected."), s_gl_info.get_version_string(), s_gl_info.get_renderer(), s_gl_info.get_vendor());
+#if SLIC3R_OPENGL_ES
+                _L("PrusaSlicer requires OpenGL ES 3.0 capable graphics driver to run correctly, \n"
+                   "while OpenGL version %s, renderer %s, vendor %s was detected."), s_gl_info.get_version_string(), s_gl_info.get_renderer(), s_gl_info.get_vendor());
 #else
-                _L("PrusaSlicer requires OpenGL 2.0 capable graphics driver to run correctly, \n"
-                   "while OpenGL version %s, render %s, vendor %s was detected."), s_gl_info.get_version_string(), s_gl_info.get_renderer(), s_gl_info.get_vendor());
-#endif // ENABLE_OPENGL_ES
+                _L("PrusaSlicer requires OpenGL 3.2 capable graphics driver to run correctly,\n"
+                   "while OpenGL version %s, renderer %s, vendor %s was detected."), s_gl_info.get_version_string(), s_gl_info.get_renderer(), s_gl_info.get_vendor());
+#endif // SLIC3R_OPENGL_ES
             message += "\n";
           	message += _L("You may need to update your graphics card driver.");
 #ifdef _WIN32
@@ -407,7 +402,7 @@ bool OpenGLManager::init_gl()
                 wxString message = format_wxstr(_L("Unable to load the following shaders:\n%s"), error);
                 wxMessageBox(message, wxString("PrusaSlicer - ") + _L("Error loading shaders"), wxOK | wxICON_ERROR);
             }
-#if ENABLE_GL_CORE_PROFILE
+#if !SLIC3R_OPENGL_ES
             if (m_debug_enabled && s_gl_info.is_version_greater_or_equal_to(4, 3) && GLEW_KHR_debug) {
                 ::glEnable(GL_DEBUG_OUTPUT);
                 ::glEnable(GL_DEBUG_OUTPUT_SYNCHRONOUS);
@@ -415,7 +410,7 @@ bool OpenGLManager::init_gl()
                 ::glDebugMessageControl(GL_DONT_CARE, GL_DONT_CARE, GL_DONT_CARE, 0, nullptr, GL_TRUE);
                 std::cout << "Enabled OpenGL debug output\n";
             }
-#endif // ENABLE_GL_CORE_PROFILE
+#endif // !SLIC3R_OPENGL_ES
         }
 
 #ifdef _WIN32
@@ -441,19 +436,19 @@ bool OpenGLManager::init_gl()
     return true;
 }
 
-#if ENABLE_GL_CORE_PROFILE
+#if SLIC3R_OPENGL_ES
+wxGLContext* OpenGLManager::init_glcontext(wxGLCanvas& canvas)
+#else
 wxGLContext* OpenGLManager::init_glcontext(wxGLCanvas& canvas, const std::pair<int, int>& required_opengl_version, bool enable_compatibility_profile,
     bool enable_debug)
-#else
-wxGLContext* OpenGLManager::init_glcontext(wxGLCanvas& canvas)
-#endif // ENABLE_GL_CORE_PROFILE
+#endif // SLIC3R_OPENGL_ES
 {
     if (m_context == nullptr) {
-#if ENABLE_OPENGL_ES
+#if SLIC3R_OPENGL_ES
         wxGLContextAttrs attrs;
         attrs.PlatformDefaults().ES2().MajorVersion(2).EndList();
         m_context = new wxGLContext(&canvas, nullptr, &attrs);
-#elif ENABLE_GL_CORE_PROFILE
+#else
         m_debug_enabled = enable_debug;
 
         const int gl_major = required_opengl_version.first;
@@ -523,9 +518,7 @@ wxGLContext* OpenGLManager::init_glcontext(wxGLCanvas& canvas)
             // if no valid context was created use the default one
             m_context = new wxGLContext(&canvas, nullptr, &attrs);
         }
-#else
-        m_context = new wxGLContext(&canvas);
-#endif // ENABLE_OPENGL_ES
+#endif // SLIC3R_OPENGL_ES
 
 #ifdef __APPLE__ 
         // Part of hack to remove crash when closing the application on OSX 10.9.5 when building against newer wxWidgets
@@ -537,75 +530,39 @@ wxGLContext* OpenGLManager::init_glcontext(wxGLCanvas& canvas)
     return m_context;
 }
 
-wxGLCanvas* OpenGLManager::create_wxglcanvas(wxWindow& parent)
+wxGLCanvas* OpenGLManager::create_wxglcanvas(wxWindow& parent, bool enable_auto_aa_samples)
 {
-#if ENABLE_GL_CORE_PROFILE || ENABLE_OPENGL_ES
     wxGLAttributes attribList;
-    attribList.PlatformDefaults().RGBA().DoubleBuffer().MinRGBA(8, 8, 8, 8).Depth(24).SampleBuffers(1).Samplers(4).EndList();
+    s_multisample = EMultisampleState::Disabled;
+    // Disable multi-sampling on ChromeOS, as the OpenGL virtualization swaps Red/Blue channels with multi-sampling enabled,
+    // at least on some platforms.
+    if (platform_flavor() != PlatformFlavor::LinuxOnChromium) {
+        for (int i = enable_auto_aa_samples ? 16 : 4; i >= 4; i /= 2) {
+            attribList.Reset();
+            attribList.PlatformDefaults().RGBA().DoubleBuffer().MinRGBA(8, 8, 8, 8).Depth(24).SampleBuffers(1).Samplers(i);
 #ifdef __APPLE__
-    // on MAC the method RGBA() has no effect
-    attribList.SetNeedsARB(true);
+            // on MAC the method RGBA() has no effect
+            attribList.SetNeedsARB(true);
 #endif // __APPLE__
-#else
-    int attribList[] = {
-        WX_GL_RGBA,
-    	WX_GL_DOUBLEBUFFER,
-    	// RGB channels each should be allocated with 8 bit depth. One should almost certainly get these bit depths by default.
-      	WX_GL_MIN_RED, 			8,
-      	WX_GL_MIN_GREEN, 		8,
-      	WX_GL_MIN_BLUE, 		8,
-      	// Requesting an 8 bit alpha channel. Interestingly, the NVIDIA drivers would most likely work with some alpha plane, but glReadPixels would not return
-      	// the alpha channel on NVIDIA if not requested when the GL context is created.
-      	WX_GL_MIN_ALPHA, 		8,
-    	WX_GL_DEPTH_SIZE, 		24,
-    	WX_GL_SAMPLE_BUFFERS, 	GL_TRUE,
-    	WX_GL_SAMPLES, 			4,
-    	0
-    };
-#endif // ENABLE_GL_CORE_PROFILE || ENABLE_OPENGL_ES
-
-    if (s_multisample == EMultisampleState::Unknown) {
-        detect_multisample(attribList);
-//        // debug output
-//        std::cout << "Multisample " << (can_multisample() ? "enabled" : "disabled") << std::endl;
+            attribList.EndList();
+            if (wxGLCanvas::IsDisplaySupported(attribList)) {
+                s_multisample = EMultisampleState::Enabled;
+                break;
+            }
+        }
     }
 
-    if (!can_multisample())
-#if ENABLE_GL_CORE_PROFILE || ENABLE_OPENGL_ES
-    {
+    if (s_multisample != EMultisampleState::Enabled) {
         attribList.Reset();
-        attribList.PlatformDefaults().RGBA().DoubleBuffer().MinRGBA(8, 8, 8, 8).Depth(24).EndList();
+        attribList.PlatformDefaults().RGBA().DoubleBuffer().MinRGBA(8, 8, 8, 8).Depth(24);
 #ifdef __APPLE__
         // on MAC the method RGBA() has no effect
         attribList.SetNeedsARB(true);
 #endif // __APPLE__
+        attribList.EndList();
     }
 
     return new wxGLCanvas(&parent, attribList, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxWANTS_CHARS);
-#else
-        attribList[12] = 0;
-
-    return new wxGLCanvas(&parent, wxID_ANY, attribList, wxDefaultPosition, wxDefaultSize, wxWANTS_CHARS);
-#endif // ENABLE_GL_CORE_PROFILE || ENABLE_OPENGL_ES
-}
-
-#if ENABLE_GL_CORE_PROFILE || ENABLE_OPENGL_ES
-void OpenGLManager::detect_multisample(const wxGLAttributes& attribList)
-#else
-void OpenGLManager::detect_multisample(int* attribList)
-#endif // ENABLE_GL_CORE_PROFILE || ENABLE_OPENGL_ES
-{
-    int wxVersion = wxMAJOR_VERSION * 10000 + wxMINOR_VERSION * 100 + wxRELEASE_NUMBER;
-    bool enable_multisample = wxVersion >= 30003;
-    s_multisample = 
-        enable_multisample &&
-        // Disable multi-sampling on ChromeOS, as the OpenGL virtualization swaps Red/Blue channels with multi-sampling enabled,
-        // at least on some platforms.
-        platform_flavor() != PlatformFlavor::LinuxOnChromium &&
-        wxGLCanvas::IsDisplaySupported(attribList)
-        ? EMultisampleState::Enabled : EMultisampleState::Disabled;
-    // Alternative method: it was working on previous version of wxWidgets but not with the latest, at least on Windows
-    // s_multisample = enable_multisample && wxGLCanvas::IsExtensionSupported("WGL_ARB_multisample");
 }
 
 } // namespace GUI
