@@ -10,7 +10,8 @@ class wxString;
 
 namespace WebView
 {
-    wxWebView *CreateWebView(wxWindow *parent, const wxString& url, const std::vector<std::string>& message_handlers);
+    wxWebView* webview_new();
+    void       webview_create(wxWebView* webview, wxWindow *parent, const wxString& url, const std::vector<std::string>& message_handlers);     
 };
 
 #endif // !slic3r_GUI_WebView_hpp_
