@@ -3,9 +3,12 @@
 
 #include <wx/event.h>
 #include <memory>
+#include <vector>
 
 #include "StateColor.hpp"
 
+class wxWindow;
+
 wxDECLARE_EVENT(EVT_ENABLE_CHANGED, wxCommandEvent);
 
 class StateHandler : public wxEvtHandler
