@@ -137,12 +137,14 @@ struct Http::priv
 	Http::ProgressFn progressfn;
 	Http::IPResolveFn ipresolvefn;
     Http::RetryFn retryfn;
+    Http::HeadersFn headersfn;
 
 	priv(const std::string &url);
 	~priv();
 
 	static bool ca_file_supported(::CURL *curl);
 	static size_t writecb(void *data, size_t size, size_t nmemb, void *userp);
+    static size_t headercb(void *data, size_t size, size_t nmemb, void *userp);
 	static int xfercb(void *userp, curl_off_t dltotal, curl_off_t dlnow, curl_off_t ultotal, curl_off_t ulnow);
 	static int xfercb_legacy(void *userp, double dltotal, double dlnow, double ultotal, double ulnow);
 	static size_t form_file_read_cb(char *buffer, size_t size, size_t nitems, void *userp);
@@ -200,7 +202,7 @@ bool Http::priv::ca_file_supported(::CURL *curl)
 
 	if (curl == nullptr) { return res; }
 
-#if LIBCURL_VERSION_MAJOR >= 7 && LIBCURL_VERSION_MINOR >= 48
+#if LIBCURL_VERSION_NUM >= 0x073000 // equivalent to v7.48 or greater
 	::curl_tlssessioninfo *tls;
 	if (::curl_easy_getinfo(curl, CURLINFO_TLS_SSL_PTR, &tls) == CURLE_OK) {
 		if (tls->backend == CURLSSLBACKEND_SCHANNEL || tls->backend == CURLSSLBACKEND_DARWINSSL) {
@@ -230,6 +232,14 @@ size_t Http::priv::writecb(void *data, size_t size, size_t nmemb, void *userp)
 	return realsize;
 }
 
+size_t Http::priv::headercb(void *data, size_t size, size_t nmemb, void *userp)
+{
+    std::string header(reinterpret_cast<char*>(data), size * nmemb);
+    std::string *header_data = static_cast<std::string*>(userp);
+    header_data->append(header);
+    return size * nmemb;
+}
+
 int Http::priv::xfercb(void *userp, curl_off_t dltotal, curl_off_t dlnow, curl_off_t ultotal, curl_off_t ulnow)
 {
 	auto self = static_cast<priv*>(userp);
@@ -364,7 +374,7 @@ void Http::priv::http_perform(const HttpRetryOpt& retry_opts)
 	::curl_easy_setopt(curl, CURLOPT_READFUNCTION, form_file_read_cb);
 
 	::curl_easy_setopt(curl, CURLOPT_NOPROGRESS, 0L);
-#if LIBCURL_VERSION_MAJOR >= 7 && LIBCURL_VERSION_MINOR >= 32
+#if LIBCURL_VERSION_NUM >= 0x072000 // equivalent to v7.32 or higher
 	::curl_easy_setopt(curl, CURLOPT_XFERINFOFUNCTION, xfercb);
 	::curl_easy_setopt(curl, CURLOPT_XFERINFODATA, static_cast<void*>(this));
 #ifndef _WIN32
@@ -377,6 +387,10 @@ void Http::priv::http_perform(const HttpRetryOpt& retry_opts)
 
 	::curl_easy_setopt(curl, CURLOPT_VERBOSE, get_logging_level() >= 5);
 
+    std::string header_data;
+    curl_easy_setopt(curl, CURLOPT_HEADERFUNCTION, headercb);
+    curl_easy_setopt(curl, CURLOPT_HEADERDATA, &header_data);
+
 	if (headerlist != nullptr) {
 		::curl_easy_setopt(curl, CURLOPT_HTTPHEADER, headerlist);
 	}
@@ -444,6 +458,9 @@ void Http::priv::http_perform(const HttpRetryOpt& retry_opts)
 		if (http_status >= 400) {
 			if (errorfn) { errorfn(std::move(buffer), std::string(), http_status); }
 		} else {
+            if (headersfn && !header_data.empty()) {
+                headersfn(header_data);
+            }
 			if (completefn) { completefn(std::move(buffer), http_status); }
 			if (ipresolvefn) {
 				char* ct;
@@ -657,6 +674,12 @@ Http& Http::on_retry(RetryFn fn)
 	return *this;
 }
 
+Http& Http::on_headers(HeadersFn fn)
+{
+	if (p) { p->headersfn = std::move(fn); }
+	return *this;
+}
+
 Http& Http::cookie_file(const std::string& file_path)
 {
 	if (p) {
