@@ -3,9 +3,16 @@
 ///|/ PrusaSlicer is released under the terms of the AGPLv3 or higher
 ///|/
 #include "WxFontUtils.hpp"
-#include <boost/assign.hpp>
+
 #include <boost/log/trivial.hpp>
-#include "libslic3r/Utils.hpp"
+#include <wx/string.h>
+#include <boost/assign/list_of.hpp>
+#include <optional>
+#include <vector>
+
+#include "libslic3r/Utils.hpp" // IWYU pragma: keep
+#include "libslic3r/Emboss.hpp"
+#include "libslic3r/Exception.hpp"
 
 #if defined(__APPLE__)
 #include <CoreText/CTFont.h>
@@ -159,12 +166,12 @@ std::string WxFontUtils::get_human_readable_name(const wxFont &font)
     if (!font.IsOk()) return "Font is NOT ok.";
     // Face name is optional in wxFont
     if (!font.GetFaceName().empty()) {
-        return std::string(font.GetFaceName().c_str());
+        return std::string(font.GetFaceName().ToUTF8().data());
     } else {
         return std::string((font.GetFamilyString() + " " +
                             font.GetStyleString() + " " +
                             font.GetWeightString())
-                               .c_str());
+                               .ToUTF8().data());
     }
 }
 
@@ -179,14 +186,14 @@ std::string WxFontUtils::store_wxFont(const wxFont &font)
         "IsFixedWidth(" << font.IsFixedWidth() << "), " <<
         "IsUsingSizeInPixels(" << font.IsUsingSizeInPixels() << "), " <<
         "Encoding(" << (int)font.GetEncoding() << "), " ;
-    return std::string(font_descriptor.c_str());
+    return std::string(font_descriptor.ToUTF8().data());
 }
 
 wxFont WxFontUtils::load_wxFont(const std::string &font_descriptor)
 {
     BOOST_LOG_TRIVIAL(trace) << "'" << font_descriptor << "'font descriptor string param of load_wxFont()";
     wxString font_descriptor_wx(font_descriptor);
-    BOOST_LOG_TRIVIAL(trace) << "'" << font_descriptor_wx.c_str() << "' wx string descriptor";
+    BOOST_LOG_TRIVIAL(trace) << "'" << font_descriptor_wx.ToUTF8().data() << "' wx string descriptor";
     wxFont wx_font(font_descriptor_wx);
     BOOST_LOG_TRIVIAL(trace) << "loaded font is '" << get_human_readable_name(wx_font) << "'.";
     return wx_font;
@@ -351,4 +358,4 @@ std::unique_ptr<Emboss::FontFile> WxFontUtils::set_bold(wxFont &font, const Embo
     // There is NO bold font by wx
     font.SetWeight(orig_weight);
     return nullptr;
-}
\ No newline at end of file
+}
