@@ -1,4 +1,4 @@
-#include <catch2/catch.hpp>
+#include <catch2/catch_test_macros.hpp>
 
 #include "test_data.hpp"
 #include "libslic3r/ClipperZUtils.hpp"
